@@ -33,6 +33,12 @@ class DeleteKeyAfterRenamingItFailedError(Exception):
 
 
 class S3Connector(ILogger):
+    LIFECYCLE_RULES_LIMIT = 1000
+
+    class LifecycleRulesLimitExceededError(Exception):
+        def __init__(self) -> None:
+            super().__init__(f"Number of lifecycle rules exceeds limit ({S3Connector.LIFECYCLE_RULES_LIMIT})")
+
     """
     S3Connector - S3 Connection Manager
     """
@@ -481,12 +487,18 @@ class S3Connector(ILogger):
         )
 
     def add_lifecycle_configuration_rule(self, rule: "LifecycleRuleTypeDef") -> None:
-        lifecycle_config = self.s3_client.get_bucket_lifecycle_configuration(Bucket=self.bucket_name)
-        if "Rules" in lifecycle_config:
-            lifecycle_config["Rules"].append(rule)
-        else:
-            lifecycle_config["Rules"] = [rule]
-        self.change_lifecycle_configuration(lifecycle_configuration={"Rules": lifecycle_config["Rules"]})
+        lifecycle_config_rules: "List[LifecycleRuleTypeDef]" = []
+        try:
+            lifecycle_config = self.s3_client.get_bucket_lifecycle_configuration(Bucket=self.bucket_name)
+            lifecycle_config_rules = lifecycle_config["Rules"] if "Rules" in lifecycle_config else []
+        except ClientError as ex:
+            self._logger.warning(f"Could not get lifecycle configuration for bucket {self.bucket_name} due to {ex}")
+        lifecycle_config_rules.append(rule)
+        if len(lifecycle_config_rules) >= int(0.8 * self.LIFECYCLE_RULES_LIMIT):
+            self._logger.warning(f"Reached 80% of the lifecycle rules limit for bucket {self.bucket_name}")
+        if len(lifecycle_config_rules) > self.LIFECYCLE_RULES_LIMIT:
+            raise S3Connector.LifecycleRulesLimitExceededError
+        self.change_lifecycle_configuration(lifecycle_configuration={"Rules": lifecycle_config_rules})
 
     def set_expiration_for_prefix(self, prefix: str, days_to_expiration: int) -> None:
         expiration_rule: "LifecycleRuleTypeDef" = {
