@@ -100,6 +100,7 @@ class HardwareMachineModel(str, Enum):
     EPYC_7003 = "m6a.4xlarge"
     SKYLAKE_SP = "m5.2xlarge"
     A100_40G = "a2-highgpu-1g"
+    A100_80G = "a2-ultragpu-1g"
     CASCADE_LAKE_GCP = "n2-standard-4"
     C5_2XLARGE = "c5.2xlarge"
 
@@ -111,7 +112,6 @@ class HardwareMachineModel(str, Enum):
     ORIN_NANO = HardwareType.ORIN_NANO.value
     ORIN_NANO_4G = HardwareType.ORIN_NANO_4G.value
     NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
-    A100_80G = HardwareType.A100_80G.value
     IMX8 = HardwareType.IMX8.value
     HAILO8 = HardwareType.HAILO8.value
     AMBARELLA = HardwareType.AMBARELLA.value
@@ -230,7 +230,7 @@ class HardwareTaint(str, Enum):
     K80 = "nvidia.com/k80gpu"
     T4 = "nvidia.com/t4gpu"
     A10G = "nvidia.com/a10gpu"
-    A100_80G = UNKNOWN
+    A100_80G = "nvidia.com/a100gpu80g"
     A100_40G = "nvidia.com/a100gpu40g"
     NANO = "nvidia.com/jetson-nano"
     XAVIER = "nvidia.com/jetson-xavier"
@@ -260,7 +260,7 @@ class HardwareLabel(str, Enum):
     K80 = "nvidia-tesla-k80"
     T4 = "nvidia-tesla-t4"
     A10G = "nvidia-ampere-a10"
-    A100_80G = UNKNOWN
+    A100_80G = "nvidia-a100-80g"
     A100_40G = "nvidia-a100-40g"
     NANO = "nvidia-jetson-nano"
     XAVIER = "nvidia-jetson-xavier"
@@ -485,9 +485,9 @@ class HardwareTypeLabel(str, Enum):
     T4 = type_with_model(HardwareMachineModel.T4)
     A10G = type_with_model(HardwareMachineModel.A10G)
     A100_40G = type_with_model(HardwareMachineModel.A100_40G, "A100 40GB")
+    A100_80G = type_with_model(HardwareMachineModel.A100_80G, "A100 80GB")
     CASCADE_LAKE_GCP = type_with_model(HardwareMachineModel.CASCADE_LAKE_GCP, "Cascade Lake")
 
-    A100_80G = HardwareType.A100_80G.value
     NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
     IMX8 = HardwareType.IMX8.value
     C5_2XLARGE = HardwareType.C5_2XLARGE.value
