@@ -2,21 +2,23 @@ from typing import Optional
 
 from deci_common.abstractions.base_model import Schema
 from deci_common.data_types.enum.hardware_enums import (
-    HardwareType,
-    InferenceHardware,
-    MapHardwareTypeToFamily,
     HardwareEnvironment,
-    HardwareVendor,
+    HardwareGroup,
+    HardwareImageDistribution,
+    HardwareImageRepository,
     HardwareLabel,
-    HardwareTaint,
-    MapHardwareTypeToVendor,
     HardwareMachineModel,
+    HardwareTaint,
+    HardwareType,
+    HardwareTypeLabel,
+    HardwareVendor,
+    InferenceHardware,
     MapHardwareTypeToEnvironment,
+    MapHardwareTypeToFamily,
+    MapHardwareTypeToGroup,
     MapHardwareTypeToImageDistribution,
     MapHardwareTypeToImageRepository,
-    HardwareGroup,
-    MapHardwareTypeToGroup,
-    HardwareTypeLabel,
+    MapHardwareTypeToVendor,
 )
 
 
@@ -26,10 +28,10 @@ class HardwareReturnSchema(Schema):
     A logic schema of hardware
     """
 
-    name: str
-    label: str
+    name: HardwareType
+    label: HardwareTypeLabel
     vendor: Optional[HardwareVendor] = None
-    machine: Optional[str] = None
+    machine: Optional[HardwareMachineModel] = None
     group: Optional[HardwareGroup] = None
     future: bool = False
     deprecated: bool = False
@@ -40,17 +42,17 @@ class Hardware(Schema):
     A logic schema of hardware
     """
 
-    name: str
+    name: HardwareType
     type: InferenceHardware
     # equals None for backwards compatibility of benchmark jobs who does not have it.
-    machine: Optional[str] = None
+    machine: Optional[HardwareMachineModel] = None
     cost_per_hour: int = 0
     environment: Optional[HardwareEnvironment]
     vendor: HardwareVendor
-    label: str
-    taint: str
-    image_repository: Optional[str]
-    image_distribution: Optional[str]
+    label: HardwareLabel
+    taint: HardwareTaint
+    image_repository: Optional[HardwareImageRepository]
+    image_distribution: Optional[HardwareImageDistribution]
 
 
 def get_hardware_by_hardware_name(hw_name: HardwareType) -> Hardware:
